@@ -67,18 +67,24 @@ class APIAlgorithm:
         :param algorithm_ids:
         :return: List[Algorithm]
         """
+        fetch_all = False
         if pagination is None:
             pagination = Pagination(
                 page_size=100
             )
+            fetch_all = True
         request = AlgorithmGetRequest(
             ids=algorithm_ids,
             pagination=pagination
         )
-        sdk_support = SDKSupport()
-        responses = await sdk_support.get_all_paginated_objects(request,
-                                                                api_function=self.__client.api.algorithm.get,
-                                                                timeout=self.__timeout)
+
+        if fetch_all:
+            sdk_support = SDKSupport()
+            responses = await sdk_support.get_all_paginated_objects(request,
+                                                                    api_function=self.__client.api.algorithm.get,
+                                                                    timeout=self.__timeout)
+        else:
+            responses = [await self.__client.api.algorithm.get(request)]
         algorithms = []
         for response in responses:
             algorithms.extend(response.algorithms)
@@ -96,15 +102,20 @@ class APIAlgorithm:
             - pagination: Pagination
         :return: List[Algorithm]
         """
-        parameters = ['search_text', 'min_created_on', 'max_created_on', 'pagination']
+        parameters = ['search_text', 'min_created_on', 'max_created_on', 'pagination', 'raw_response']
         for key in kwargs.keys():
             assert key in parameters
 
         message_fragments = []
+        fetch_all = False
         if 'pagination' not in kwargs.keys():
             message_fragments.append((AlgorithmListRequest(pagination=Pagination(
                 page_size=100
             ))))
+            fetch_all = True
+
+        if 'raw_response' not in kwargs.keys():
+            kwargs['raw_response'] = False
 
         for key in kwargs.keys():
             if key == 'search_text':
@@ -126,14 +137,24 @@ class APIAlgorithm:
         for fragment in message_fragments:
             request.MergeFrom(fragment)
 
-        sdk_support = SDKSupport()
-        responses = await sdk_support.get_all_paginated_objects(request,
-                                                                api_function=self.__client.api.algorithm.list,
-                                                                timeout=self.__timeout)
-        algorithms = []
-        for response in responses:
-            algorithms.extend(response.algorithms)
-        return algorithms
+        if fetch_all:
+            sdk_support = SDKSupport()
+            responses = await sdk_support.get_all_paginated_objects(request,
+                                                                    api_function=self.__client.api.algorithm.list,
+                                                                    timeout=self.__timeout)
+            if kwargs['raw_response']:
+                return responses
+            else:
+                algorithms = []
+                for response in responses:
+                    algorithms.extend(response.algorithms)
+                return algorithms
+        else:
+            response = await self.__client.api.algorithm.list(request, timeout=self.__timeout)
+            if kwargs['raw_response']:
+                return response
+            else:
+                return response.algorithms
 
 
 class APIAlgorithmVersion:
@@ -221,10 +242,16 @@ class APIAlgorithmVersion:
         """
 
         message_fragments = []
+        fetch_all = False
         if 'pagination' not in kwargs.keys():
             message_fragments.append((AlgorithmVersionListRequest(pagination=Pagination(
                 page_size=100
             ))))
+            fetch_all = True
+
+        if 'raw_response' not in kwargs.keys():
+            kwargs['raw_response'] = False
+
 
         for key in kwargs.keys():
             if key == 'algorithm_id':
@@ -253,14 +280,24 @@ class APIAlgorithmVersion:
             request.MergeFrom(fragment)
         MessageToDict(request)
 
-        sdk_support = SDKSupport()
-        responses = await sdk_support.get_all_paginated_objects(request,
-                                                                api_function=self.__client.api.algorithm_version.list,
-                                                                timeout=self.__timeout)
-        algorithm_versions = []
-        for response in responses:
-            algorithm_versions.extend(response.algorithm_versions)
-        return algorithm_versions
+        if fetch_all:
+            sdk_support = SDKSupport()
+            responses = await sdk_support.get_all_paginated_objects(request,
+                                                                    api_function=self.__client.api.algorithm_version.list,
+                                                                    timeout=self.__timeout)
+            if kwargs['raw_response']:
+                return responses
+            else:
+                algorithm_versions = []
+                for response in responses:
+                    algorithm_versions.extend(response.algorithm_versions)
+                return algorithm_versions
+        else:
+            response = await self.__client.api.algorithm_version.list(request, timeout=self.__timeout)
+            if kwargs['raw_response']:
+                return response
+            else:
+                return response.algorithm_versions
 
     async def deprecate(self, ids: List):
         """
@@ -383,11 +420,16 @@ class APIAlgorithmConfig:
         :return: List[AlgorithmConfig]
         """
         message_fragments = []
+        fetch_all = False
         if 'pagination' not in kwargs.keys():
             message_fragments.append(AlgorithmConfigListRequest(
                 pagination=Pagination(
                     page_size=100
                 )))
+            fetch_all = True
+        if 'raw_response' not in kwargs.keys():
+            kwargs['raw_response'] = False
+
         if 'include_deactivated' not in kwargs.keys():
             message_fragments.append(AlgorithmConfigListRequest(
                 include_deactivated=False
@@ -428,14 +470,24 @@ class APIAlgorithmConfig:
         for fragment in message_fragments:
             request.MergeFrom(fragment)
 
-        sdk_support = SDKSupport()
-        responses = await sdk_support.get_all_paginated_objects(request,
-                                                                api_function=self.__client.api.algorithm_config.list,
-                                                                timeout=self.__timeout)
-        algorithm_configs = []
-        for response in responses:
-            algorithm_configs.extend(response.algorithm_configs)
-        return algorithm_configs
+        if fetch_all:
+            sdk_support = SDKSupport()
+            responses = await sdk_support.get_all_paginated_objects(request,
+                                                                    api_function=self.__client.api.algorithm_config.list,
+                                                                    timeout=self.__timeout)
+            if kwargs['raw_response']:
+                algorithm_configs = []
+                for response in responses:
+                    algorithm_configs.extend(response.algorithm_configs)
+                return algorithm_configs
+            else:
+                return responses
+        else:
+            response = await self.__client.api.algorithm_config.list(request, timeout=self.__timeout)
+            if kwargs['raw_response']:
+                return response
+            else:
+                return response.algorithm_configs
 
     async def deprecate(self, algorithm_config_ids: List):
         """
