@@ -94,10 +94,17 @@ class APIAnalysis:
         :return: List[Analysis]
         """
         request_fragments = []
+        fetch_all = False
         if 'pagination' not in kwargs.keys():
             request_fragments.append((AnalysisListRequest(pagination=Pagination(
                 page_size=100
             ))))
+            fetch_all = True
+
+        if 'raw_response' not in kwargs.keys():
+            kwargs['raw_response'] = False
+
+
         for key in kwargs.keys():
             if key == 'search_text':
                 assert isinstance(kwargs[key], str)
@@ -117,15 +124,26 @@ class APIAnalysis:
         for param in request_fragments:
             request.MergeFrom(param)
 
-        sdk_support = SDKSupport()
-        responses = await sdk_support.get_all_paginated_objects(request,
-                                                                api_function=self.__client.api.analysis.list,
-                                                                timeout=self.__timeout)
-        analyses = []
-        for response in responses:
-            analyses.extend(response.analyses)
+        if fetch_all:
+            sdk_support = SDKSupport()
+            responses = await sdk_support.get_all_paginated_objects(request,
+                                                                    api_function=self.__client.api.analysis.list,
+                                                                    timeout=self.__timeout)
+            if kwargs['raw_response']:
+                return responses
+            else:
+                analyses = []
+                for response in responses:
+                    analyses.extend(response.analyses)
 
-        return analyses
+                return analyses
+        else:
+            response = await self.__client.api.analysis.list(request, timeout=self.__timeout)
+
+            if kwargs['raw_response']:
+                return response
+            else:
+                return response.analyses
 
 
 class APIAnalysisVersion:
@@ -204,10 +222,16 @@ class APIAnalysisVersion:
         assert kwargs.keys() is not None
 
         request_fragments = []
+        fetch_all = False
         if 'pagination' not in kwargs.keys():
             request_fragments.append((AnalysisVersionListRequest(pagination=Pagination(
                 page_size=100
             ))))
+            fetch_all = True
+
+        if 'raw_response' not in kwargs.keys():
+            kwargs['raw_response'] = False
+
         if 'include_manifest' not in kwargs.keys():
             request_fragments.append(AnalysisVersionListRequest(include_manifest=False))
 
@@ -238,14 +262,25 @@ class APIAnalysisVersion:
         for request_fragment in request_fragments:
             request.MergeFrom(request_fragment)
 
-        sdk_support = SDKSupport()
-        responses = await sdk_support.get_all_paginated_objects(request,
-                                                                api_function=self.__client.api.analysis_version.list,
-                                                                timeout=self.__timeout)
-        analysis_versions = []
-        for response in responses:
-            analysis_versions.extend(response.analysis_versions)
-        return analysis_versions
+        if fetch_all:
+            sdk_support = SDKSupport()
+            responses = await sdk_support.get_all_paginated_objects(request,
+                                                                    api_function=self.__client.api.analysis_version.list,
+                                                                    timeout=self.__timeout)
+            if kwargs['raw_response']:
+                return responses
+            else:
+                analysis_versions = []
+                for response in responses:
+                    analysis_versions.extend(response.analysis_versions)
+                return analysis_versions
+        else:
+            response = await self.__client.api.analysis_version.list(request, timeout=self.__timeout)
+
+            if kwargs['raw_response']:
+                return response
+            else:
+                return response.analysis_versions
 
     async def deprecate(self, analysis_version_ids: List):
         """
@@ -363,10 +398,15 @@ class APIAnalysisConfig:
         assert kwargs.keys() is not None
 
         request_fragments = []
+        fetch_all = False
         if 'pagination' not in kwargs.keys():
             request_fragments.append(AnalysisConfigListRequest(pagination=Pagination(
                 page_size=100
             )))
+            fetch_all = True
+
+        if 'raw_response' not in kwargs.keys():
+            kwargs['raw_response'] = False
 
         for key in kwargs.keys():
             if key == 'analysis_id':
@@ -397,14 +437,26 @@ class APIAnalysisConfig:
         request = AnalysisConfigListRequest()
         for request_fragment in request_fragments:
             request.MergeFrom(request_fragment)
-        sdk_support = SDKSupport()
-        responses = await sdk_support.get_all_paginated_objects(request,
-                                                                api_function=self.__client.api.analysis_config.list,
-                                                                timeout=self.__timeout)
-        analysis_configs = []
-        for response in responses:
-            analysis_configs.extend(response.analysis_configs)
-        return analysis_configs
+
+        if fetch_all:
+            sdk_support = SDKSupport()
+            responses = await sdk_support.get_all_paginated_objects(request,
+                                                                    api_function=self.__client.api.analysis_config.list,
+                                                                    timeout=self.__timeout)
+            if kwargs['raw_response']:
+                return responses
+            else:
+                analysis_configs = []
+                for response in responses:
+                    analysis_configs.extend(response.analysis_configs)
+                return analysis_configs
+        else:
+            response = await self.__client.api.analysis_config.list(request)
+
+            if kwargs['raw_response']:
+                return response
+            else:
+                return response.analysis_configs
 
     async def deprecate(self, analysis_config_ids: List):
         """
