@@ -27,7 +27,8 @@ class DataSource(Enum):
     XMODE = "xmode_pings"
     CUEBIQ = "cuebiq_pings"
     BLOGWATCHER = "blogwatcher_pings"
-    SPIRE = "spire"
+    SPIRE = "spire_pings"
+    SPIRE_NMEA = "spire_nmea_pings"
     CUEBIQ_WORKBENCH = "cuebiq-workbench_pings"
     WEJO = "wejo_pings"
     HAWKEYE360 = "hawkeye360_pings"
@@ -46,6 +47,7 @@ class DataSource(Enum):
     CUEBIQ_TRACKS = "cuebiq_track_pings"
     BLOGWATCHER_TRACKS = "blogwatcher_track_pings"
     SPIRE_TRACKS = "spire_track_pings"
+    SPIRE_NMEA_TRACKS = "spire_nmea_track_pings"
     CUEBIQ_WORKBENCH_TRACKS = "cuebiq-workbench_track_pings"
     WEJO_TRACKS = "wejo_track_pings"
     HAWKEYE360_TRACKS = "hawkeye360_track_pings"
@@ -56,7 +58,7 @@ class DataSource(Enum):
     PLANET_PSORTHOTILE = "planet_OSOrthoTile"
     PLANET_PSSCENE4BAND = "planet_PSScene4Band"
     PLANET_SKYSATSCENE = "planet_SkySatScene"
-    PLANET_SKYSATCOLLECT = "planet_SkySatCollection"
+    PLANET_SKYSATCOLLECT = "planet_SkySatCollect"
     AIRBUS_SPOT7 = "airbus_SPOT7"
     AIRBUS_PHR1A = "airbus_PHR1A"
     AIRBUS_PHR1B = "airbus_PHR1B"
@@ -205,6 +207,8 @@ class AlgorithmManifest:
             entry['min_count'] = kwargs['min_count']
         if 'max_count' in kwargs.keys():
             entry['max_count'] = kwargs['max_count']
+        if 'parameters' in kwargs.keys():
+            entry['parameters'] = kwargs['parameters']
 
         self.__inputs.append(entry.copy())
         self.__required['inputs'] = True
