@@ -114,7 +114,7 @@ class TestAlgorithm:
             algorithm_ids.append(algorithm_model.id)
 
         # search text
-        algorithms = await sdk.algorithm.list(search_text=name, pagination=Pagination(page_size=5))
+        algorithms = await sdk.algorithm.list(search_text=name)
         assert len(algorithm_ids) == len(algorithms)
         algorithms = await sdk.algorithm.list(min_created_on=now, max_created_on=halfway)
         assert len(algorithms) == algorithm_count / 2
@@ -253,8 +253,7 @@ class TestAlgorithmVersion:
             algorithm_version_ids.append(algorithm_version.id)
 
         algorithm_versions = await sdk.algorithm_version.list(algorithm_id=algorithm.id,
-                                                              include_all_versions=True,
-                                                              pagination=Pagination(page_size=5))
+                                                              include_all_versions=True)
         assert len(algorithm_versions) == len(algorithm_version_ids)
 
         algorithm_versions = await sdk.algorithm_version.list(tag=tag_search_key, include_all_versions=True)
@@ -568,7 +567,8 @@ class TestAlgorithmConfig:
 
         configurations = await sdk.algorithm_config.list()
         assert len(configurations) > 0
-        configurations = await sdk.algorithm_config.list(algorithm_id=algorithm.id, pagination=Pagination(page_size=5))
+        configurations = await sdk.algorithm_config.list(algorithm_version_id=algorithm_version.id,
+                                                         include_all_versions=True)
         assert len(config_ids) == config_count == len(configurations)
 
     @pytest.mark.asyncio
