@@ -196,8 +196,7 @@ class TestAnalysis:
                 time.sleep(10)
                 halfway = datetime.utcnow()
 
-        results = await sdk.analysis.list(search_text=str(search_text),
-                                          pagination=Pagination(page_size=5))
+        results = await sdk.analysis.list(search_text=str(search_text))
         assert len(results) == analysis_count
 
         search_results = await sdk.analysis.list(min_created_on=start, max_created_on=halfway)
@@ -283,8 +282,7 @@ class TestAnalysisVersion:
 
         analysis_versions = await sdk.analysis_version.list(min_created_on=min_created_on,
                                                             max_created_on=max_created_on,
-                                                            include_all_versions=True,
-                                                            pagination=Pagination(page_size=5))
+                                                            include_all_versions=True)
         assert len(analysis_versions) == analysis_version_id_count / 2
 
     @pytest.mark.asyncio
@@ -357,8 +355,7 @@ class TestAnalysisConfig:
             analysis_config = await analysis_config_create(analysis_version.id, algorithm_config.id, manifest)
             analysis_config_ids.append(analysis_config.id)
 
-        analysis_configs = await sdk.analysis_config.list(analysis_version_id=analysis_version.id,
-                                                          pagination=Pagination(page_size=5))
+        analysis_configs = await sdk.analysis_config.list(analysis_version_id=analysis_version.id)
         assert len(analysis_configs) == config_count
 
     @pytest.mark.asyncio
